Production native RPC adapters over the same database, sessions, and SQL query registry used by the HTTP server.
Structs
- Native
External Auth - Native bearer authentication backed by hardened core verifiers.
- Native
Runtime - All seven native services backed by the canonical server runtime.