Module native

Module native 

Production native RPC adapters over the same database, sessions, and SQL query registry used by the HTTP server.

Structs

NativeExternalAuth
Native bearer authentication backed by hardened core verifiers.
NativeRuntime
All seven native services backed by the canonical server runtime.